==> kwin-5.21.4-1-armv6h.pkg.tar.xz: usr/lib/cmake/KWinEffects/KWinEffectsTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KWinEffects::kwinxrenderutils" for configuration ""
set_property(TARGET KWinEffects::kwinxrenderutils APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KWinEffects::kwinxrenderutils PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkwinxrenderutils.so.5.21.4"
  IMPORTED_SONAME_NOCONFIG "libkwinxrenderutils.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwinxrenderutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwinxrenderutils "${_IMPORT_PREFIX}/lib/libkwinxrenderutils.so.5.21.4" )

# Import target "KWinEffects::kwineffects" for configuration ""
set_property(TARGET KWinEffects::kwineffects APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KWinEffects::kwineffects PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Quick;KF5::Declarative;KWinEffects::kwinglutils;KWinEffects::kwinxrenderutils"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkwineffects.so.5.21.4"
  IMPORTED_SONAME_NOCONFIG "libkwineffects.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwineffects )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwineffects "${_IMPORT_PREFIX}/lib/libkwineffects.so.5.21.4" )

# Import target "KWinEffects::kwinglutils" for configuration ""
set_property(TARGET KWinEffects::kwinglutils APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KWinEffects::kwinglutils PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkwinglutils.so.5.21.4"
  IMPORTED_SONAME_NOCONFIG "libkwinglutils.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwinglutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwinglutils "${_IMPORT_PREFIX}/lib/libkwinglutils.so.5.21.4" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kwin-5.22.4-1-armv6h.pkg.tar.xz: usr/lib/cmake/KWinEffects/KWinEffectsTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KWinEffects::kwinxrenderutils" for configuration ""
set_property(TARGET KWinEffects::kwinxrenderutils APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KWinEffects::kwinxrenderutils PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkwinxrenderutils.so.5.22.4"
  IMPORTED_SONAME_NOCONFIG "libkwinxrenderutils.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwinxrenderutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwinxrenderutils "${_IMPORT_PREFIX}/lib/libkwinxrenderutils.so.5.22.4" )

# Import target "KWinEffects::kwineffects" for configuration ""
set_property(TARGET KWinEffects::kwineffects APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KWinEffects::kwineffects PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::Declarative;KWinEffects::kwinglutils;KWinEffects::kwinxrenderutils"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkwineffects.so.5.22.4"
  IMPORTED_SONAME_NOCONFIG "libkwineffects.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwineffects )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwineffects "${_IMPORT_PREFIX}/lib/libkwineffects.so.5.22.4" )

# Import target "KWinEffects::kwinglutils" for configuration ""
set_property(TARGET KWinEffects::kwinglutils APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KWinEffects::kwinglutils PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkwinglutils.so.5.22.4"
  IMPORTED_SONAME_NOCONFIG "libkwinglutils.so.13"
  )

list(APPEND _IMPORT_CHECK_TARGETS KWinEffects::kwinglutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KWinEffects::kwinglutils "${_IMPORT_PREFIX}/lib/libkwinglutils.so.5.22.4" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
